function v=compute_tangential_surge_xshift(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes tangential_surge_xshift
% Script automatically generated by fit_tangential_surge_xshift.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.60588
% RMSE  = 6.8675
% MEAN  = 1.2739
% RANGE = -24.4566 - 22.8213

beta( 1 )= 5.1921e+00 ;
beta( 2 )= 1.2346e+01 ;
beta( 3 )= -6.5610e+00 ;
beta( 4 )= -2.1073e-02 ;
beta( 5 )= 4.8573e-04 ;
beta( 6 )= 2.0440e+01 ;
beta( 7 )= 2.7723e+00 ;

v = beta(1) + beta(2)*sin(beta(7)*(phi-beta(3))*pi/180)+beta(4).*vmax + beta(5).*w + beta(6).*a;
